# tatara-python

The official python client for Tatara.

## Releasing a new version

Follow the instructions in [this tutorial](https://www.digitalocean.com/community/tutorials/how-to-publish-python-packages-to-pypi-using-poetry-on-ubuntu-22-04)
to release a new version of the package.

## Testing

`poetry run pytest`
